# USB-Imager

[USB-Imager] is a GUI tool to write bootable disk images to USB key.

|[License]   | GPLv3
|--------    | --------
|*Copyright* | **&copy; 2021-2022 by Secu-Design&reg;**
- - - - - - -

![Screenshot]


## 1. Features

- No root privileges required.
- Drives get automatically unmounted and locked (if encrypted) before writing.
- Writing support for hybrid ISOs by checking the MBR signature.
- Adjustable write buffer

Planned:

- Automatic deactivation of LVM2 volumes before writing
- Write to multiple USB keys simultaneously
- Checksum verification after copying
- Multilanguage support
- Flatpak support


## 2. Installation

- **pip / pipenv:**

    If the distribution's own package manager is not supported yet, the USB-Imager can alternatively be installed via the Python package manager `pip`.

    ```bash
    $ pip install usb-imager
    $ pip uninstall usb-imager
    ```

    or [pipenv]:

    ```bash
    $ pipenv install usb-imager
    $ pipenv run usb-imager
    $ pipenv uninstall usb-imager
    ```


## 3. Usage

Start USB-Imager via the desktop icon or just type `usb-imager` in your terminal window.


## 4. Notice:

**Pip installation with Debian based linux (Ubuntu, Linux Mint, ...):**

~/.local/bin may not be included in the executable search path due to a [bug], you have to manually add the directory to the PATH environment variable by adding it to ~/.profile in this case.

```bash
$ PATH=~/.local/bin:$PATH
```


## 5. Support

If you want to report a bug or request a feature, you can do so [here].
You can also write an email to [Skynet-Devel].

## 6. Acknowledgements

Thanks to:

- My loved ones for their almost infinite patience.



[USB-Imager]: https://pypi.org/project/usb-imager/
[License]: https://www.gnu.org/licenses/gpl-3.0-standalone.html
[Screenshot]: https://gitlab.com/skynet-devel/usb-imager/-/raw/master/Screenshot.webp
[Skynet-Devel]: mailto:skynet-devel@secure.mailbox.org

[pipenv]: https://pypi.org/project/pipenv/
[here]: https://gitlab.com/skynet-devel/usb-imager/issues

[bug]: https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=820856
